Method: PKCS11::Session#C_FindObjectsInit

Defined in:
lib/pkcs11/session.rb

#C_FindObjectsInit(find_template = {}) ⇒ PKCS11::Session

Initializes a search for token and session objects that match a template.

See #find_objects for convenience. The matching criterion is an exact byte-for-byte match with all attributes in the template. Use empty Hash to find all objects.

Parameters:

  • find_template (Hash) (defaults to: {})

    points to a search template that specifies the attribute values to match

Returns:



81
82
83
84
# File 'lib/pkcs11/session.rb', line 81

def C_FindObjectsInit(find_template={})
  @pk.C_FindObjectsInit(@sess, to_attributes(find_template))
  self
end